@@ -175,6 +175,7 @@ struct _ValaCCodeBlockPrivate {
 };
 
 
+static gpointer vala_ccode_block_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -213,7 +214,6 @@ ValaCCodeBlock* vala_ccode_block_new (void);
 ValaCCodeBlock* vala_ccode_block_construct (GType object_type);
 ValaCCodeBlock* vala_ccode_block_new (void);
 void vala_ccode_block_set_suppress_newline (ValaCCodeBlock* self, gboolean value);
-static gpointer vala_ccode_block_parent_class = NULL;
 static void vala_ccode_block_finalize (ValaCCodeNode* obj);
 
 
@@ -250,9 +250,12 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 	{
 		GeeIterator* _statement_it;
 		_statement_it = gee_iterable_iterator ((GeeIterable*) self->priv->statements);
-		while (gee_iterator_next (_statement_it)) {
+		while (TRUE) {
 			ValaCCodeNode* statement;
 			gboolean _tmp0_;
+			if (!gee_iterator_next (_statement_it)) {
+				break;
+			}
 			statement = (ValaCCodeNode*) gee_iterator_get (_statement_it);
 			vala_ccode_node_write_declaration (statement, writer);
 			_tmp0_ = FALSE;
@@ -303,8 +306,11 @@ static void vala_ccode_block_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 	{
 		GeeIterator* _statement_it;
 		_statement_it = gee_iterable_iterator ((GeeIterable*) self->priv->statements);
-		while (gee_iterator_next (_statement_it)) {
+		while (TRUE) {
 			ValaCCodeNode* statement;
+			if (!gee_iterator_next (_statement_it)) {
+				break;
+			}
 			statement = (ValaCCodeNode*) gee_iterator_get (_statement_it);
 			vala_ccode_node_write (statement, writer);
 			/* only output reachable code*/
@@ -340,8 +346,10 @@ ValaCCodeBlock* vala_ccode_block_new (void) {
 
 
 gboolean vala_ccode_block_get_suppress_newline (ValaCCodeBlock* self) {
+	gboolean result;
 	g_return_val_if_fail (self != NULL, FALSE);
-	return self->priv->_suppress_newline;
+	result = self->priv->_suppress_newline;
+	return result;
 }
 
 
