@@ -148,6 +148,7 @@ struct _ValaCCodeFunctionPrivate {
 };
 
 
+static gpointer vala_ccode_function_parent_class = NULL;
 
 gpointer vala_ccode_node_ref (gpointer instance);
 void vala_ccode_node_unref (gpointer instance);
@@ -190,7 +191,6 @@ void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
 void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
 void vala_ccode_writer_write_newline (ValaCCodeWriter* self);
 static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
-static gpointer vala_ccode_function_parent_class = NULL;
 static void vala_ccode_function_finalize (ValaCCodeNode* obj);
 
 
@@ -229,6 +229,7 @@ void vala_ccode_function_add_parameter (ValaCCodeFunction* self, ValaCCodeFormal
  * @return copied function
  */
 ValaCCodeFunction* vala_ccode_function_copy (ValaCCodeFunction* self) {
+	ValaCCodeFunction* result;
 	ValaCCodeFunction* func;
 	g_return_val_if_fail (self != NULL, NULL);
 	func = vala_ccode_function_new (self->priv->_name, self->priv->_return_type);
@@ -245,8 +246,17 @@ ValaCCodeFunction* vala_ccode_function_copy (ValaCCodeFunction* self) {
 		/* no deep copy for lists available yet
 		 * func.parameters = parameters.copy ();
 		 */
-		while (gee_iterator_next (_param_it)) {
+		while (TRUE) {
 			ValaCCodeFormalParameter* param;
+			/* no deep copy for lists available yet
+			 * func.parameters = parameters.copy ();
+			 */
+			if (!gee_iterator_next (_param_it)) {
+				/* no deep copy for lists available yet
+				 * func.parameters = parameters.copy ();
+				 */
+				break;
+			}
 			/* no deep copy for lists available yet
 			 * func.parameters = parameters.copy ();
 			 */
@@ -257,7 +267,8 @@ ValaCCodeFunction* vala_ccode_function_copy (ValaCCodeFunction* self) {
 		(_param_it == NULL) ? NULL : (_param_it = (gee_collection_object_unref (_param_it), NULL));
 	}
 	vala_ccode_function_set_block (func, self->priv->_block);
-	return func;
+	result = func;
+	return result;
 }
 
 
@@ -281,8 +292,11 @@ static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter
 	{
 		GeeIterator* _param_it;
 		_param_it = gee_iterable_iterator ((GeeIterable*) self->priv->parameters);
-		while (gee_iterator_next (_param_it)) {
+		while (TRUE) {
 			ValaCCodeFormalParameter* param;
+			if (!gee_iterator_next (_param_it)) {
+				break;
+			}
 			param = (ValaCCodeFormalParameter*) gee_iterator_get (_param_it);
 			if (!first) {
 				vala_ccode_writer_write_string (writer, ", ");
@@ -309,24 +323,28 @@ static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter
 
 
 const char* vala_ccode_function_get_name (ValaCCodeFunction* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_name;
+	result = self->priv->_name;
+	return result;
 }
 
 
 void vala_ccode_function_set_name (ValaCCodeFunction* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp1_);
 }
 
 
 ValaCCodeModifiers vala_ccode_function_get_modifiers (ValaCCodeFunction* self) {
+	ValaCCodeModifiers result;
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->_modifiers;
+	result = self->priv->_modifiers;
+	return result;
 }
 
 
@@ -337,34 +355,38 @@ void vala_ccode_function_set_modifiers (ValaCCodeFunction* self, ValaCCodeModifi
 
 
 const char* vala_ccode_function_get_return_type (ValaCCodeFunction* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_return_type;
+	result = self->priv->_return_type;
+	return result;
 }
 
 
 void vala_ccode_function_set_return_type (ValaCCodeFunction* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_return_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_return_type = (g_free (self->priv->_return_type), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_return_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_return_type = (g_free (self->priv->_return_type), NULL), _tmp1_);
 }
 
 
 ValaCCodeBlock* vala_ccode_function_get_block (ValaCCodeFunction* self) {
+	ValaCCodeBlock* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_block;
+	result = self->priv->_block;
+	return result;
 }
 
 
 void vala_ccode_function_set_block (ValaCCodeFunction* self, ValaCCodeBlock* value) {
-	ValaCCodeBlock* _tmp2_;
 	ValaCCodeBlock* _tmp1_;
+	ValaCCodeBlock* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_block = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_ccode_node_ref (_tmp1_)), (self->priv->_block == NULL) ? NULL : (self->priv->_block = (vala_ccode_node_unref (self->priv->_block), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_block = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_ccode_node_ref (_tmp0_)), (self->priv->_block == NULL) ? NULL : (self->priv->_block = (vala_ccode_node_unref (self->priv->_block), NULL)), _tmp1_);
 }
 
 
