@@ -62,6 +62,7 @@ struct _ValaParamSpecCCodeCompiler {
 };
 
 
+static gpointer vala_ccode_compiler_parent_class = NULL;
 
 gpointer vala_ccode_compiler_ref (gpointer instance);
 void vala_ccode_compiler_unref (gpointer instance);
@@ -77,7 +78,6 @@ ValaCCodeCompiler* vala_ccode_compiler_construct (GType object_type);
 ValaCCodeCompiler* vala_ccode_compiler_new (void);
 static gboolean vala_ccode_compiler_package_exists (const char* package_name);
 void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* context, const char* cc_command, char** cc_options, int cc_options_length1);
-static gpointer vala_ccode_compiler_parent_class = NULL;
 static void vala_ccode_compiler_finalize (ValaCCodeCompiler* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
@@ -96,6 +96,7 @@ ValaCCodeCompiler* vala_ccode_compiler_new (void) {
 
 
 static gboolean vala_ccode_compiler_package_exists (const char* package_name) {
+	gboolean result;
 	GError * _inner_error_;
 	char* pc;
 	gint exit_status;
@@ -104,7 +105,6 @@ static gboolean vala_ccode_compiler_package_exists (const char* package_name) {
 	pc = g_strconcat ("pkg-config --exists ", package_name, NULL);
 	exit_status = 0;
 	{
-		gboolean _tmp0_;
 		g_spawn_command_line_sync (pc, NULL, NULL, &exit_status, &_inner_error_);
 		if (_inner_error_ != NULL) {
 			if (_inner_error_->domain == G_SPAWN_ERROR) {
@@ -112,7 +112,9 @@ static gboolean vala_ccode_compiler_package_exists (const char* package_name) {
 			}
 			goto __finally0;
 		}
-		return (_tmp0_ = 0 == exit_status, pc = (g_free (pc), NULL), _tmp0_);
+		result = 0 == exit_status;
+		pc = (g_free (pc), NULL);
+		return result;
 	}
 	goto __finally0;
 	__catch0_g_spawn_error:
@@ -121,9 +123,11 @@ static gboolean vala_ccode_compiler_package_exists (const char* package_name) {
 		e = _inner_error_;
 		_inner_error_ = NULL;
 		{
-			gboolean _tmp1_;
 			vala_report_error (NULL, e->message);
-			return (_tmp1_ = FALSE, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), pc = (g_free (pc), NULL), _tmp1_);
+			result = FALSE;
+			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
+			pc = (g_free (pc), NULL);
+			return result;
 		}
 	}
 	__finally0:
@@ -182,8 +186,11 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		_tmp3_ = NULL;
 		_tmp4_ = NULL;
 		_pkg_it = (_tmp4_ = gee_iterable_iterator ((GeeIterable*) (_tmp3_ = vala_code_context_get_packages (context))), (_tmp3_ == NULL) ? NULL : (_tmp3_ = (gee_collection_object_unref (_tmp3_), NULL)), _tmp4_);
-		while (gee_iterator_next (_pkg_it)) {
+		while (TRUE) {
 			char* pkg;
+			if (!gee_iterator_next (_pkg_it)) {
+				break;
+			}
 			pkg = (char*) gee_iterator_get (_pkg_it);
 			if (vala_ccode_compiler_package_exists (pkg)) {
 				char* _tmp6_;
@@ -307,8 +314,11 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	{
 		GeeIterator* _file_it;
 		_file_it = gee_iterable_iterator ((GeeIterable*) source_files);
-		while (gee_iterator_next (_file_it)) {
+		while (TRUE) {
 			ValaSourceFile* file;
+			if (!gee_iterator_next (_file_it)) {
+				break;
+			}
 			file = (ValaSourceFile*) gee_iterator_get (_file_it);
 			if (!vala_source_file_get_external_package (file)) {
 				char* _tmp24_;
@@ -332,11 +342,14 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	{
 		GeeIterator* _file_it;
 		_file_it = gee_iterable_iterator ((GeeIterable*) c_source_files);
-		while (gee_iterator_next (_file_it)) {
+		while (TRUE) {
 			char* file;
 			char* _tmp27_;
 			char* _tmp26_;
 			char* _tmp25_;
+			if (!gee_iterator_next (_file_it)) {
+				break;
+			}
 			file = (char*) gee_iterator_get (_file_it);
 			_tmp27_ = NULL;
 			_tmp26_ = NULL;
@@ -427,9 +440,14 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		/* remove generated C source and header files */
 		_file_it = gee_iterable_iterator ((GeeIterable*) source_files);
 		/* remove generated C source and header files */
-		while (gee_iterator_next (_file_it)) {
+		while (TRUE) {
 			ValaSourceFile* file;
 			/* remove generated C source and header files */
+			if (!gee_iterator_next (_file_it)) {
+				/* remove generated C source and header files */
+				break;
+			}
+			/* remove generated C source and header files */
 			file = (ValaSourceFile*) gee_iterator_get (_file_it);
 			if (!vala_source_file_get_external_package (file)) {
 				if (!vala_code_context_get_save_csources (context)) {
