@@ -279,6 +279,7 @@ struct _ValaClassTypePrivate {
 };
 
 
+static gpointer vala_class_type_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -341,7 +342,6 @@ ValaDataType* vala_data_type_copy (ValaDataType* self);
 static ValaDataType* vala_class_type_real_copy (ValaDataType* base);
 char* vala_typesymbol_get_cname (ValaTypeSymbol* self, gboolean const_type);
 static char* vala_class_type_real_get_cname (ValaDataType* base);
-static gpointer vala_class_type_parent_class = NULL;
 static void vala_class_type_finalize (ValaCodeNode* obj);
 
 
@@ -362,6 +362,7 @@ ValaClassType* vala_class_type_new (ValaClass* class_symbol) {
 
 static ValaDataType* vala_class_type_real_copy (ValaDataType* base) {
 	ValaClassType * self;
+	ValaDataType* result;
 	ValaClassType* _result_;
 	self = (ValaClassType*) base;
 	_result_ = vala_class_type_new (self->priv->_class_symbol);
@@ -377,9 +378,12 @@ static ValaDataType* vala_class_type_real_copy (ValaDataType* base) {
 		_tmp0_ = NULL;
 		_tmp1_ = NULL;
 		_arg_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_data_type_get_type_arguments ((ValaDataType*) self))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
-		while (gee_iterator_next (_arg_it)) {
+		while (TRUE) {
 			ValaDataType* arg;
 			ValaDataType* _tmp2_;
+			if (!gee_iterator_next (_arg_it)) {
+				break;
+			}
 			arg = (ValaDataType*) gee_iterator_get (_arg_it);
 			_tmp2_ = NULL;
 			vala_data_type_add_type_argument ((ValaDataType*) _result_, _tmp2_ = vala_data_type_copy (arg));
@@ -388,24 +392,29 @@ static ValaDataType* vala_class_type_real_copy (ValaDataType* base) {
 		}
 		(_arg_it == NULL) ? NULL : (_arg_it = (gee_collection_object_unref (_arg_it), NULL));
 	}
-	return (ValaDataType*) _result_;
+	result = (ValaDataType*) _result_;
+	return result;
 }
 
 
 static char* vala_class_type_real_get_cname (ValaDataType* base) {
 	ValaClassType * self;
+	char* result;
 	char* _tmp0_;
 	char* _tmp1_;
 	self = (ValaClassType*) base;
 	_tmp0_ = NULL;
 	_tmp1_ = NULL;
-	return (_tmp1_ = g_strdup_printf ("%sClass*", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_class_symbol, FALSE)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	result = (_tmp1_ = g_strdup_printf ("%sClass*", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_class_symbol, FALSE)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
+	return result;
 }
 
 
 ValaClass* vala_class_type_get_class_symbol (ValaClassType* self) {
+	ValaClass* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_class_symbol;
+	result = self->priv->_class_symbol;
+	return result;
 }
 
 
