@@ -425,6 +425,16 @@ typedef struct _ValaSwitchSectionClass ValaSwitchSectionClass;
 typedef struct _ValaSwitchLabel ValaSwitchLabel;
 typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;
 
+#define VALA_TYPE_LOOP (vala_loop_get_type ())
+#define VALA_LOOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOOP, ValaLoop))
+#define VALA_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOOP, ValaLoopClass))
+#define VALA_IS_LOOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOOP))
+#define VALA_IS_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOOP))
+#define VALA_LOOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOOP, ValaLoopClass))
+
+typedef struct _ValaLoop ValaLoop;
+typedef struct _ValaLoopClass ValaLoopClass;
+
 #define VALA_TYPE_WHILE_STATEMENT (vala_while_statement_get_type ())
 #define VALA_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatement))
 #define VALA_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))
@@ -882,6 +892,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_switch_statement) (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
 	void (*visit_switch_section) (ValaCodeVisitor* self, ValaSwitchSection* section);
 	void (*visit_switch_label) (ValaCodeVisitor* self, ValaSwitchLabel* label);
+	void (*visit_loop) (ValaCodeVisitor* self, ValaLoop* stmt);
 	void (*visit_while_statement) (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 	void (*visit_do_statement) (ValaCodeVisitor* self, ValaDoStatement* stmt);
 	void (*visit_for_statement) (ValaCodeVisitor* self, ValaForStatement* stmt);
@@ -938,6 +949,7 @@ struct _ValaCodeGeneratorClass {
 };
 
 
+static gpointer vala_code_generator_parent_class = NULL;
 
 gpointer vala_code_visitor_ref (gpointer instance);
 void vala_code_visitor_unref (gpointer instance);
@@ -994,6 +1006,7 @@ GType vala_if_statement_get_type (void);
 GType vala_switch_statement_get_type (void);
 GType vala_switch_section_get_type (void);
 GType vala_switch_label_get_type (void);
+GType vala_loop_get_type (void);
 GType vala_while_statement_get_type (void);
 GType vala_do_statement_get_type (void);
 GType vala_for_statement_get_type (void);
@@ -1048,7 +1061,6 @@ static void vala_code_generator_real_emit (ValaCodeGenerator* self, ValaCodeCont
 ValaCodeGenerator* vala_code_generator_new (void);
 ValaCodeGenerator* vala_code_generator_construct (GType object_type);
 ValaCodeGenerator* vala_code_generator_new (void);
-static gpointer vala_code_generator_parent_class = NULL;
 
 
 
