@@ -236,6 +236,7 @@ struct _ValaDelegateTypePrivate {
 };
 
 
+static gpointer vala_delegate_type_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -289,7 +290,6 @@ static GeeList* vala_delegate_type_real_get_symbols (ValaDataType* base);
 static char* vala_delegate_type_real_get_type_id (ValaDataType* base);
 gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
 static gboolean vala_delegate_type_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
-static gpointer vala_delegate_type_parent_class = NULL;
 static void vala_delegate_type_finalize (ValaCodeNode* obj);
 
 
@@ -310,29 +310,36 @@ ValaDelegateType* vala_delegate_type_new (ValaDelegate* delegate_symbol) {
 
 static gboolean vala_delegate_type_real_is_invokable (ValaDataType* base) {
 	ValaDelegateType * self;
+	gboolean result;
 	self = (ValaDelegateType*) base;
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
 static ValaDataType* vala_delegate_type_real_get_return_type (ValaDataType* base) {
 	ValaDelegateType * self;
+	ValaDataType* result;
 	ValaDataType* _tmp0_;
 	self = (ValaDelegateType*) base;
 	_tmp0_ = NULL;
-	return (_tmp0_ = vala_delegate_get_return_type (self->priv->_delegate_symbol), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+	result = (_tmp0_ = vala_delegate_get_return_type (self->priv->_delegate_symbol), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+	return result;
 }
 
 
 static GeeList* vala_delegate_type_real_get_parameters (ValaDataType* base) {
 	ValaDelegateType * self;
+	GeeList* result;
 	self = (ValaDelegateType*) base;
-	return vala_delegate_get_parameters (self->priv->_delegate_symbol);
+	result = vala_delegate_get_parameters (self->priv->_delegate_symbol);
+	return result;
 }
 
 
 static char* vala_delegate_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope) {
 	ValaDelegateType * self;
+	char* result;
 	char* s;
 	self = (ValaDelegateType*) base;
 	s = vala_symbol_get_full_name ((ValaSymbol*) self->priv->_delegate_symbol);
@@ -341,62 +348,75 @@ static char* vala_delegate_type_real_to_qualified_string (ValaDataType* base, Va
 		_tmp0_ = NULL;
 		s = (_tmp0_ = g_strconcat (s, "?", NULL), s = (g_free (s), NULL), _tmp0_);
 	}
-	return s;
+	result = s;
+	return result;
 }
 
 
 static ValaDataType* vala_delegate_type_real_copy (ValaDataType* base) {
 	ValaDelegateType * self;
+	ValaDataType* result;
 	self = (ValaDelegateType*) base;
-	return (ValaDataType*) vala_delegate_type_new (self->priv->_delegate_symbol);
+	result = (ValaDataType*) vala_delegate_type_new (self->priv->_delegate_symbol);
+	return result;
 }
 
 
 static char* vala_delegate_type_real_get_cname (ValaDataType* base) {
 	ValaDelegateType * self;
+	char* result;
 	self = (ValaDelegateType*) base;
-	return vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_delegate_symbol, FALSE);
+	result = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_delegate_symbol, FALSE);
+	return result;
 }
 
 
 static GeeList* vala_delegate_type_real_get_symbols (ValaDataType* base) {
 	ValaDelegateType * self;
+	GeeList* result;
 	GeeArrayList* symbols;
 	self = (ValaDelegateType*) base;
 	symbols = gee_array_list_new (VALA_TYPE_SYMBOL, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
 	gee_collection_add ((GeeCollection*) symbols, (ValaSymbol*) self->priv->_delegate_symbol);
-	return (GeeList*) symbols;
+	result = (GeeList*) symbols;
+	return result;
 }
 
 
 static char* vala_delegate_type_real_get_type_id (ValaDataType* base) {
 	ValaDelegateType * self;
+	char* result;
 	self = (ValaDelegateType*) base;
-	return g_strdup ("G_TYPE_POINTER");
+	result = g_strdup ("G_TYPE_POINTER");
+	return result;
 }
 
 
 static gboolean vala_delegate_type_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaDelegateType * self;
+	gboolean result;
 	self = (ValaDelegateType*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
-	return vala_code_node_check ((ValaCodeNode*) self->priv->_delegate_symbol, analyzer);
+	result = vala_code_node_check ((ValaCodeNode*) self->priv->_delegate_symbol, analyzer);
+	return result;
 }
 
 
 ValaDelegate* vala_delegate_type_get_delegate_symbol (ValaDelegateType* self) {
+	ValaDelegate* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_delegate_symbol;
+	result = self->priv->_delegate_symbol;
+	return result;
 }
 
 
 void vala_delegate_type_set_delegate_symbol (ValaDelegateType* self, ValaDelegate* value) {
-	ValaDelegate* _tmp2_;
 	ValaDelegate* _tmp1_;
+	ValaDelegate* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_delegate_symbol = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_delegate_symbol == NULL) ? NULL : (self->priv->_delegate_symbol = (vala_code_node_unref (self->priv->_delegate_symbol), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_delegate_symbol = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_delegate_symbol == NULL) ? NULL : (self->priv->_delegate_symbol = (vala_code_node_unref (self->priv->_delegate_symbol), NULL)), _tmp1_);
 }
 
 
