@@ -236,6 +236,7 @@ struct _ValaFieldPrototypePrivate {
 };
 
 
+static gpointer vala_field_prototype_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -277,7 +278,6 @@ ValaField* vala_field_prototype_get_field_symbol (ValaFieldPrototype* self);
 static ValaDataType* vala_field_prototype_real_copy (ValaDataType* base);
 char* vala_symbol_get_full_name (ValaSymbol* self);
 static char* vala_field_prototype_real_to_qualified_string (ValaDataType* base, ValaScope* scope);
-static gpointer vala_field_prototype_parent_class = NULL;
 static void vala_field_prototype_finalize (ValaCodeNode* obj);
 
 
@@ -298,33 +298,39 @@ ValaFieldPrototype* vala_field_prototype_new (ValaField* field_symbol) {
 
 static ValaDataType* vala_field_prototype_real_copy (ValaDataType* base) {
 	ValaFieldPrototype * self;
+	ValaDataType* result;
 	ValaFieldPrototype* _result_;
 	self = (ValaFieldPrototype*) base;
 	_result_ = vala_field_prototype_new (self->priv->_field_symbol);
-	return (ValaDataType*) _result_;
+	result = (ValaDataType*) _result_;
+	return result;
 }
 
 
 static char* vala_field_prototype_real_to_qualified_string (ValaDataType* base, ValaScope* scope) {
 	ValaFieldPrototype * self;
+	char* result;
 	self = (ValaFieldPrototype*) base;
-	return vala_symbol_get_full_name ((ValaSymbol*) self->priv->_field_symbol);
+	result = vala_symbol_get_full_name ((ValaSymbol*) self->priv->_field_symbol);
+	return result;
 }
 
 
 ValaField* vala_field_prototype_get_field_symbol (ValaFieldPrototype* self) {
+	ValaField* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_field_symbol;
+	result = self->priv->_field_symbol;
+	return result;
 }
 
 
 void vala_field_prototype_set_field_symbol (ValaFieldPrototype* self, ValaField* value) {
-	ValaField* _tmp2_;
 	ValaField* _tmp1_;
+	ValaField* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_field_symbol = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_field_symbol == NULL) ? NULL : (self->priv->_field_symbol = (vala_code_node_unref (self->priv->_field_symbol), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_field_symbol = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_field_symbol == NULL) ? NULL : (self->priv->_field_symbol = (vala_code_node_unref (self->priv->_field_symbol), NULL)), _tmp1_);
 }
 
 
