@@ -303,6 +303,7 @@ typedef enum  {
 } ValaUnaryOperator;
 
 
+static gpointer vala_initializer_list_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -388,7 +389,6 @@ gboolean vala_data_type_compatible (ValaDataType* self, ValaDataType* target_typ
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
 static gboolean vala_initializer_list_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 gint vala_initializer_list_get_size (ValaInitializerList* self);
-static gpointer vala_initializer_list_parent_class = NULL;
 static void vala_initializer_list_finalize (ValaCodeNode* obj);
 
 
@@ -412,8 +412,10 @@ void vala_initializer_list_append (ValaInitializerList* self, ValaExpression* ex
  * @return expression list
  */
 GeeList* vala_initializer_list_get_initializers (ValaInitializerList* self) {
+	GeeList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return (GeeList*) gee_read_only_list_new (VALA_TYPE_EXPRESSION, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->initializers);
+	result = (GeeList*) gee_read_only_list_new (VALA_TYPE_EXPRESSION, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, self->priv->initializers);
+	return result;
 }
 
 
@@ -444,8 +446,11 @@ static void vala_initializer_list_real_accept_children (ValaCodeNode* base, Vala
 	{
 		GeeIterator* _expr_it;
 		_expr_it = gee_iterable_iterator ((GeeIterable*) self->priv->initializers);
-		while (gee_iterator_next (_expr_it)) {
+		while (TRUE) {
 			ValaExpression* expr;
+			if (!gee_iterator_next (_expr_it)) {
+				break;
+			}
 			expr = (ValaExpression*) gee_iterator_get (_expr_it);
 			vala_code_node_accept ((ValaCodeNode*) expr, visitor);
 			(expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL));
@@ -465,22 +470,29 @@ static void vala_initializer_list_real_accept (ValaCodeNode* base, ValaCodeVisit
 
 static gboolean vala_initializer_list_real_is_pure (ValaExpression* base) {
 	ValaInitializerList * self;
+	gboolean result;
 	self = (ValaInitializerList*) base;
 	{
 		GeeIterator* _initializer_it;
 		_initializer_it = gee_iterable_iterator ((GeeIterable*) self->priv->initializers);
-		while (gee_iterator_next (_initializer_it)) {
+		while (TRUE) {
 			ValaExpression* initializer;
+			if (!gee_iterator_next (_initializer_it)) {
+				break;
+			}
 			initializer = (ValaExpression*) gee_iterator_get (_initializer_it);
 			if (!vala_expression_is_pure (initializer)) {
-				gboolean _tmp0;
-				return (_tmp0 = FALSE, (initializer == NULL) ? NULL : (initializer = (vala_code_node_unref (initializer), NULL)), (_initializer_it == NULL) ? NULL : (_initializer_it = (gee_collection_object_unref (_initializer_it), NULL)), _tmp0);
+				result = FALSE;
+				(initializer == NULL) ? NULL : (initializer = (vala_code_node_unref (initializer), NULL));
+				(_initializer_it == NULL) ? NULL : (_initializer_it = (gee_collection_object_unref (_initializer_it), NULL));
+				return result;
 			}
 			(initializer == NULL) ? NULL : (initializer = (vala_code_node_unref (initializer), NULL));
 		}
 		(_initializer_it == NULL) ? NULL : (_initializer_it = (gee_collection_object_unref (_initializer_it), NULL));
 	}
-	return TRUE;
+	result = TRUE;
+	return result;
 }
 
 
@@ -492,12 +504,23 @@ static void vala_initializer_list_real_replace_expression (ValaCodeNode* base, V
 	{
 		gint i;
 		i = 0;
-		for (; i < gee_collection_get_size ((GeeCollection*) self->priv->initializers); i++) {
-			ValaExpression* _tmp0;
-			gboolean _tmp1;
-			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = (ValaExpression*) gee_list_get (self->priv->initializers, i)) == old_node, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
-				gee_list_set (self->priv->initializers, i, new_node);
+		{
+			gboolean _tmp0_;
+			_tmp0_ = TRUE;
+			while (TRUE) {
+				ValaExpression* _tmp1_;
+				gboolean _tmp2_;
+				if (!_tmp0_) {
+					i++;
+				}
+				_tmp0_ = FALSE;
+				if (!(i < gee_collection_get_size ((GeeCollection*) self->priv->initializers))) {
+					break;
+				}
+				_tmp1_ = NULL;
+				if ((_tmp2_ = (_tmp1_ = (ValaExpression*) gee_list_get (self->priv->initializers, i)) == old_node, (_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL)), _tmp2_)) {
+					gee_list_set (self->priv->initializers, i, new_node);
+				}
 			}
 		}
 	}
@@ -506,89 +529,98 @@ static void vala_initializer_list_real_replace_expression (ValaCodeNode* base, V
 
 static gboolean vala_initializer_list_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaInitializerList * self;
-	gboolean error;
+	gboolean result;
+	gboolean _error_;
 	self = (ValaInitializerList*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	if (vala_expression_get_target_type ((ValaExpression*) self) == NULL) {
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "initializer list used for unknown type");
-		return FALSE;
+		result = FALSE;
+		return result;
 	} else {
 		if (VALA_IS_ARRAY_TYPE (vala_expression_get_target_type ((ValaExpression*) self))) {
-			ValaArrayType* _tmp2;
+			ValaArrayType* _tmp0_;
 			ValaArrayType* array_type;
-			gboolean _tmp3;
-			gboolean _tmp4;
+			gboolean _tmp1_;
+			gboolean _tmp2_;
 			ValaDataType* inner_target_type;
 			/* initializer is used as array initializer */
-			_tmp2 = NULL;
-			array_type = (_tmp2 = VALA_ARRAY_TYPE (vala_expression_get_target_type ((ValaExpression*) self)), (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2));
-			_tmp3 = FALSE;
-			_tmp4 = FALSE;
+			_tmp0_ = NULL;
+			array_type = (_tmp0_ = VALA_ARRAY_TYPE (vala_expression_get_target_type ((ValaExpression*) self)), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+			_tmp1_ = FALSE;
+			_tmp2_ = FALSE;
 			if (!VALA_IS_ARRAY_CREATION_EXPRESSION (vala_code_node_get_parent_node ((ValaCodeNode*) self))) {
-				_tmp4 = !VALA_IS_CONSTANT (vala_code_node_get_parent_node ((ValaCodeNode*) self));
+				_tmp2_ = !VALA_IS_CONSTANT (vala_code_node_get_parent_node ((ValaCodeNode*) self));
 			} else {
-				_tmp4 = FALSE;
+				_tmp2_ = FALSE;
 			}
-			if (_tmp4) {
-				_tmp3 = !VALA_IS_INITIALIZER_LIST (vala_code_node_get_parent_node ((ValaCodeNode*) self));
+			if (_tmp2_) {
+				_tmp1_ = !VALA_IS_INITIALIZER_LIST (vala_code_node_get_parent_node ((ValaCodeNode*) self));
 			} else {
-				_tmp3 = FALSE;
+				_tmp1_ = FALSE;
 			}
-			if (_tmp3) {
-				ValaCodeNode* _tmp5;
+			if (_tmp1_) {
+				ValaCodeNode* _tmp3_;
 				ValaCodeNode* old_parent_node;
-				ValaDataType* _tmp6;
-				ValaArrayCreationExpression* _tmp7;
+				ValaDataType* _tmp4_;
+				ValaArrayCreationExpression* _tmp5_;
 				ValaArrayCreationExpression* array_creation;
-				gboolean _tmp8;
 				/* transform shorthand form
 				     int[] array = { 42 };
 				 into
 				     int[] array = new int[] { 42 };*/
-				_tmp5 = NULL;
-				old_parent_node = (_tmp5 = vala_code_node_get_parent_node ((ValaCodeNode*) self), (_tmp5 == NULL) ? NULL : vala_code_node_ref (_tmp5));
-				_tmp6 = NULL;
-				_tmp7 = NULL;
-				array_creation = (_tmp7 = vala_array_creation_expression_new (_tmp6 = vala_data_type_copy (vala_array_type_get_element_type (array_type)), vala_array_type_get_rank (array_type), self, vala_code_node_get_source_reference ((ValaCodeNode*) self)), (_tmp6 == NULL) ? NULL : (_tmp6 = (vala_code_node_unref (_tmp6), NULL)), _tmp7);
+				_tmp3_ = NULL;
+				old_parent_node = (_tmp3_ = vala_code_node_get_parent_node ((ValaCodeNode*) self), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_));
+				_tmp4_ = NULL;
+				_tmp5_ = NULL;
+				array_creation = (_tmp5_ = vala_array_creation_expression_new (_tmp4_ = vala_data_type_copy (vala_array_type_get_element_type (array_type)), vala_array_type_get_rank (array_type), self, vala_code_node_get_source_reference ((ValaCodeNode*) self)), (_tmp4_ == NULL) ? NULL : (_tmp4_ = (vala_code_node_unref (_tmp4_), NULL)), _tmp5_);
 				vala_expression_set_target_type ((ValaExpression*) array_creation, vala_expression_get_target_type ((ValaExpression*) self));
 				vala_code_node_replace_expression (old_parent_node, (ValaExpression*) self, (ValaExpression*) array_creation);
 				vala_code_node_set_checked ((ValaCodeNode*) self, FALSE);
-				return (_tmp8 = vala_code_node_check ((ValaCodeNode*) array_creation, analyzer), (old_parent_node == NULL) ? NULL : (old_parent_node = (vala_code_node_unref (old_parent_node), NULL)), (array_creation == NULL) ? NULL : (array_creation = (vala_code_node_unref (array_creation), NULL)), (array_type == NULL) ? NULL : (array_type = (vala_code_node_unref (array_type), NULL)), _tmp8);
+				result = vala_code_node_check ((ValaCodeNode*) array_creation, analyzer);
+				(old_parent_node == NULL) ? NULL : (old_parent_node = (vala_code_node_unref (old_parent_node), NULL));
+				(array_creation == NULL) ? NULL : (array_creation = (vala_code_node_unref (array_creation), NULL));
+				(array_type == NULL) ? NULL : (array_type = (vala_code_node_unref (array_type), NULL));
+				return result;
 			}
 			inner_target_type = NULL;
 			if (vala_array_type_get_rank (array_type) > 1) {
 				ValaArrayType* inner_array_type;
-				gint _tmp9;
-				ValaDataType* _tmp11;
-				ValaDataType* _tmp10;
+				gint _tmp6_;
+				ValaDataType* _tmp8_;
+				ValaDataType* _tmp7_;
 				/* allow initialization of multi-dimensional arrays*/
 				inner_array_type = VALA_ARRAY_TYPE (vala_data_type_copy ((ValaDataType*) array_type));
-				_tmp9 = vala_array_type_get_rank (inner_array_type);
-				vala_array_type_set_rank (inner_array_type, _tmp9 - 1);
-				_tmp9;
-				_tmp11 = NULL;
-				_tmp10 = NULL;
-				inner_target_type = (_tmp11 = (_tmp10 = (ValaDataType*) inner_array_type, (_tmp10 == NULL) ? NULL : vala_code_node_ref (_tmp10)), (inner_target_type == NULL) ? NULL : (inner_target_type = (vala_code_node_unref (inner_target_type), NULL)), _tmp11);
+				_tmp6_ = vala_array_type_get_rank (inner_array_type);
+				vala_array_type_set_rank (inner_array_type, _tmp6_ - 1);
+				_tmp6_;
+				_tmp8_ = NULL;
+				_tmp7_ = NULL;
+				inner_target_type = (_tmp8_ = (_tmp7_ = (ValaDataType*) inner_array_type, (_tmp7_ == NULL) ? NULL : vala_code_node_ref (_tmp7_)), (inner_target_type == NULL) ? NULL : (inner_target_type = (vala_code_node_unref (inner_target_type), NULL)), _tmp8_);
 				(inner_array_type == NULL) ? NULL : (inner_array_type = (vala_code_node_unref (inner_array_type), NULL));
 			} else {
-				ValaDataType* _tmp12;
-				_tmp12 = NULL;
-				inner_target_type = (_tmp12 = vala_data_type_copy (vala_array_type_get_element_type (array_type)), (inner_target_type == NULL) ? NULL : (inner_target_type = (vala_code_node_unref (inner_target_type), NULL)), _tmp12);
+				ValaDataType* _tmp9_;
+				_tmp9_ = NULL;
+				inner_target_type = (_tmp9_ = vala_data_type_copy (vala_array_type_get_element_type (array_type)), (inner_target_type == NULL) ? NULL : (inner_target_type = (vala_code_node_unref (inner_target_type), NULL)), _tmp9_);
 			}
 			{
-				GeeList* _tmp13;
-				GeeIterator* _tmp14;
+				GeeList* _tmp10_;
+				GeeIterator* _tmp11_;
 				GeeIterator* _e_it;
-				_tmp13 = NULL;
-				_tmp14 = NULL;
-				_e_it = (_tmp14 = gee_iterable_iterator ((GeeIterable*) (_tmp13 = vala_initializer_list_get_initializers (self))), (_tmp13 == NULL) ? NULL : (_tmp13 = (gee_collection_object_unref (_tmp13), NULL)), _tmp14);
-				while (gee_iterator_next (_e_it)) {
+				_tmp10_ = NULL;
+				_tmp11_ = NULL;
+				_e_it = (_tmp11_ = gee_iterable_iterator ((GeeIterable*) (_tmp10_ = vala_initializer_list_get_initializers (self))), (_tmp10_ == NULL) ? NULL : (_tmp10_ = (gee_collection_object_unref (_tmp10_), NULL)), _tmp11_);
+				while (TRUE) {
 					ValaExpression* e;
+					if (!gee_iterator_next (_e_it)) {
+						break;
+					}
 					e = (ValaExpression*) gee_iterator_get (_e_it);
 					vala_expression_set_target_type (e, inner_target_type);
 					(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
@@ -599,56 +631,67 @@ static gboolean vala_initializer_list_real_check (ValaCodeNode* base, ValaSemant
 			(inner_target_type == NULL) ? NULL : (inner_target_type = (vala_code_node_unref (inner_target_type), NULL));
 		} else {
 			if (VALA_IS_STRUCT (vala_data_type_get_data_type (vala_expression_get_target_type ((ValaExpression*) self)))) {
-				ValaStruct* _tmp15;
+				ValaStruct* _tmp12_;
 				ValaStruct* st;
-				GeeList* _tmp16;
-				GeeIterator* _tmp17;
+				GeeList* _tmp13_;
+				GeeIterator* _tmp14_;
 				GeeIterator* field_it;
 				/* initializer is used as struct initializer */
-				_tmp15 = NULL;
-				st = (_tmp15 = VALA_STRUCT (vala_data_type_get_data_type (vala_expression_get_target_type ((ValaExpression*) self))), (_tmp15 == NULL) ? NULL : vala_code_node_ref (_tmp15));
-				_tmp16 = NULL;
-				_tmp17 = NULL;
-				field_it = (_tmp17 = gee_iterable_iterator ((GeeIterable*) (_tmp16 = vala_struct_get_fields (st))), (_tmp16 == NULL) ? NULL : (_tmp16 = (gee_collection_object_unref (_tmp16), NULL)), _tmp17);
+				_tmp12_ = NULL;
+				st = (_tmp12_ = VALA_STRUCT (vala_data_type_get_data_type (vala_expression_get_target_type ((ValaExpression*) self))), (_tmp12_ == NULL) ? NULL : vala_code_node_ref (_tmp12_));
+				_tmp13_ = NULL;
+				_tmp14_ = NULL;
+				field_it = (_tmp14_ = gee_iterable_iterator ((GeeIterable*) (_tmp13_ = vala_struct_get_fields (st))), (_tmp13_ == NULL) ? NULL : (_tmp13_ = (gee_collection_object_unref (_tmp13_), NULL)), _tmp14_);
 				{
-					GeeList* _tmp18;
-					GeeIterator* _tmp19;
+					GeeList* _tmp15_;
+					GeeIterator* _tmp16_;
 					GeeIterator* _e_it;
-					_tmp18 = NULL;
-					_tmp19 = NULL;
-					_e_it = (_tmp19 = gee_iterable_iterator ((GeeIterable*) (_tmp18 = vala_initializer_list_get_initializers (self))), (_tmp18 == NULL) ? NULL : (_tmp18 = (gee_collection_object_unref (_tmp18), NULL)), _tmp19);
-					while (gee_iterator_next (_e_it)) {
+					_tmp15_ = NULL;
+					_tmp16_ = NULL;
+					_e_it = (_tmp16_ = gee_iterable_iterator ((GeeIterable*) (_tmp15_ = vala_initializer_list_get_initializers (self))), (_tmp15_ == NULL) ? NULL : (_tmp15_ = (gee_collection_object_unref (_tmp15_), NULL)), _tmp16_);
+					while (TRUE) {
 						ValaExpression* e;
 						ValaField* field;
-						ValaDataType* _tmp25;
+						ValaDataType* _tmp21_;
+						if (!gee_iterator_next (_e_it)) {
+							break;
+						}
 						e = (ValaExpression*) gee_iterator_get (_e_it);
 						field = NULL;
-						while (field == NULL) {
-							ValaField* _tmp23;
-							if (!gee_iterator_next (field_it)) {
-								char* _tmp21;
-								char* _tmp20;
-								gboolean _tmp22;
-								vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-								_tmp21 = NULL;
-								_tmp20 = NULL;
-								vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), _tmp21 = g_strdup_printf ("too many expressions in initializer list for `%s'", _tmp20 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_target_type ((ValaExpression*) self))));
-								_tmp21 = (g_free (_tmp21), NULL);
-								_tmp20 = (g_free (_tmp20), NULL);
-								return (_tmp22 = FALSE, (e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL)), (field == NULL) ? NULL : (field = (vala_code_node_unref (field), NULL)), (_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL)), (st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL)), (field_it == NULL) ? NULL : (field_it = (gee_collection_object_unref (field_it), NULL)), _tmp22);
+						while (TRUE) {
+							ValaField* _tmp19_;
+							if (!(field == NULL)) {
+								break;
 							}
-							_tmp23 = NULL;
-							field = (_tmp23 = (ValaField*) gee_iterator_get (field_it), (field == NULL) ? NULL : (field = (vala_code_node_unref (field), NULL)), _tmp23);
+							if (!gee_iterator_next (field_it)) {
+								char* _tmp18_;
+								char* _tmp17_;
+								vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+								_tmp18_ = NULL;
+								_tmp17_ = NULL;
+								vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), _tmp18_ = g_strdup_printf ("too many expressions in initializer list for `%s'", _tmp17_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_target_type ((ValaExpression*) self))));
+								_tmp18_ = (g_free (_tmp18_), NULL);
+								_tmp17_ = (g_free (_tmp17_), NULL);
+								result = FALSE;
+								(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
+								(field == NULL) ? NULL : (field = (vala_code_node_unref (field), NULL));
+								(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
+								(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
+								(field_it == NULL) ? NULL : (field_it = (gee_collection_object_unref (field_it), NULL));
+								return result;
+							}
+							_tmp19_ = NULL;
+							field = (_tmp19_ = (ValaField*) gee_iterator_get (field_it), (field == NULL) ? NULL : (field = (vala_code_node_unref (field), NULL)), _tmp19_);
 							if (vala_field_get_binding (field) != MEMBER_BINDING_INSTANCE) {
-								ValaField* _tmp24;
+								ValaField* _tmp20_;
 								/* we only initialize instance fields*/
-								_tmp24 = NULL;
-								field = (_tmp24 = NULL, (field == NULL) ? NULL : (field = (vala_code_node_unref (field), NULL)), _tmp24);
+								_tmp20_ = NULL;
+								field = (_tmp20_ = NULL, (field == NULL) ? NULL : (field = (vala_code_node_unref (field), NULL)), _tmp20_);
 							}
 						}
-						_tmp25 = NULL;
-						vala_expression_set_target_type (e, _tmp25 = vala_data_type_copy (vala_field_get_field_type (field)));
-						(_tmp25 == NULL) ? NULL : (_tmp25 = (vala_code_node_unref (_tmp25), NULL));
+						_tmp21_ = NULL;
+						vala_expression_set_target_type (e, _tmp21_ = vala_data_type_copy (vala_field_get_field_type (field)));
+						(_tmp21_ == NULL) ? NULL : (_tmp21_ = (vala_code_node_unref (_tmp21_), NULL));
 						if (!vala_data_type_get_value_owned (vala_expression_get_target_type ((ValaExpression*) self))) {
 							vala_data_type_set_value_owned (vala_expression_get_target_type (e), FALSE);
 						}
@@ -660,80 +703,87 @@ static gboolean vala_initializer_list_real_check (ValaCodeNode* base, ValaSemant
 				(st == NULL) ? NULL : (st = (vala_code_node_unref (st), NULL));
 				(field_it == NULL) ? NULL : (field_it = (gee_collection_object_unref (field_it), NULL));
 			} else {
-				char* _tmp27;
-				char* _tmp26;
+				char* _tmp23_;
+				char* _tmp22_;
 				vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-				_tmp27 = NULL;
-				_tmp26 = NULL;
-				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp27 = g_strdup_printf ("initializer list used for `%s', which is neither array nor struct", _tmp26 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_target_type ((ValaExpression*) self))));
-				_tmp27 = (g_free (_tmp27), NULL);
-				_tmp26 = (g_free (_tmp26), NULL);
-				return FALSE;
+				_tmp23_ = NULL;
+				_tmp22_ = NULL;
+				vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp23_ = g_strdup_printf ("initializer list used for `%s', which is neither array nor struct", _tmp22_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_target_type ((ValaExpression*) self))));
+				_tmp23_ = (g_free (_tmp23_), NULL);
+				_tmp22_ = (g_free (_tmp22_), NULL);
+				result = FALSE;
+				return result;
 			}
 		}
 	}
 	{
 		GeeIterator* _expr_it;
 		_expr_it = gee_iterable_iterator ((GeeIterable*) self->priv->initializers);
-		while (gee_iterator_next (_expr_it)) {
+		while (TRUE) {
 			ValaExpression* expr;
+			if (!gee_iterator_next (_expr_it)) {
+				break;
+			}
 			expr = (ValaExpression*) gee_iterator_get (_expr_it);
 			vala_code_node_check ((ValaCodeNode*) expr, analyzer);
 			(expr == NULL) ? NULL : (expr = (vala_code_node_unref (expr), NULL));
 		}
 		(_expr_it == NULL) ? NULL : (_expr_it = (gee_collection_object_unref (_expr_it), NULL));
 	}
-	error = FALSE;
+	_error_ = FALSE;
 	{
-		GeeList* _tmp29;
-		GeeIterator* _tmp30;
+		GeeList* _tmp24_;
+		GeeIterator* _tmp25_;
 		GeeIterator* _e_it;
-		_tmp29 = NULL;
-		_tmp30 = NULL;
-		_e_it = (_tmp30 = gee_iterable_iterator ((GeeIterable*) (_tmp29 = vala_initializer_list_get_initializers (self))), (_tmp29 == NULL) ? NULL : (_tmp29 = (gee_collection_object_unref (_tmp29), NULL)), _tmp30);
-		while (gee_iterator_next (_e_it)) {
+		_tmp24_ = NULL;
+		_tmp25_ = NULL;
+		_e_it = (_tmp25_ = gee_iterable_iterator ((GeeIterable*) (_tmp24_ = vala_initializer_list_get_initializers (self))), (_tmp24_ == NULL) ? NULL : (_tmp24_ = (gee_collection_object_unref (_tmp24_), NULL)), _tmp25_);
+		while (TRUE) {
 			ValaExpression* e;
-			ValaUnaryExpression* _tmp32;
-			ValaExpression* _tmp31;
+			ValaUnaryExpression* _tmp27_;
+			ValaExpression* _tmp26_;
 			ValaUnaryExpression* unary;
-			gboolean _tmp33;
+			gboolean _tmp28_;
+			if (!gee_iterator_next (_e_it)) {
+				break;
+			}
 			e = (ValaExpression*) gee_iterator_get (_e_it);
 			if (vala_expression_get_value_type (e) == NULL) {
-				error = TRUE;
+				_error_ = TRUE;
 				(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
 				continue;
 			}
-			_tmp32 = NULL;
-			_tmp31 = NULL;
-			unary = (_tmp32 = (_tmp31 = e, VALA_IS_UNARY_EXPRESSION (_tmp31) ? ((ValaUnaryExpression*) _tmp31) : NULL), (_tmp32 == NULL) ? NULL : vala_code_node_ref (_tmp32));
-			_tmp33 = FALSE;
+			_tmp27_ = NULL;
+			_tmp26_ = NULL;
+			unary = (_tmp27_ = (_tmp26_ = e, VALA_IS_UNARY_EXPRESSION (_tmp26_) ? ((ValaUnaryExpression*) _tmp26_) : NULL), (_tmp27_ == NULL) ? NULL : vala_code_node_ref (_tmp27_));
+			_tmp28_ = FALSE;
 			if (unary != NULL) {
-				gboolean _tmp34;
-				_tmp34 = FALSE;
+				gboolean _tmp29_;
+				_tmp29_ = FALSE;
 				if (vala_unary_expression_get_operator (unary) == VALA_UNARY_OPERATOR_REF) {
-					_tmp34 = TRUE;
+					_tmp29_ = TRUE;
 				} else {
-					_tmp34 = vala_unary_expression_get_operator (unary) == VALA_UNARY_OPERATOR_OUT;
+					_tmp29_ = vala_unary_expression_get_operator (unary) == VALA_UNARY_OPERATOR_OUT;
 				}
-				_tmp33 = _tmp34;
+				_tmp28_ = _tmp29_;
 			} else {
-				_tmp33 = FALSE;
+				_tmp28_ = FALSE;
 			}
-			if (_tmp33) {
+			if (_tmp28_) {
 			} else {
 				if (!vala_data_type_compatible (vala_expression_get_value_type (e), vala_expression_get_target_type (e))) {
-					char* _tmp37;
-					char* _tmp36;
-					char* _tmp35;
-					error = TRUE;
+					char* _tmp32_;
+					char* _tmp31_;
+					char* _tmp30_;
+					_error_ = TRUE;
 					vala_code_node_set_error ((ValaCodeNode*) e, TRUE);
-					_tmp37 = NULL;
-					_tmp36 = NULL;
-					_tmp35 = NULL;
-					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), _tmp37 = g_strdup_printf ("Expected initializer of type `%s' but got `%s'", _tmp35 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_target_type (e)), _tmp36 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (e))));
-					_tmp37 = (g_free (_tmp37), NULL);
-					_tmp36 = (g_free (_tmp36), NULL);
-					_tmp35 = (g_free (_tmp35), NULL);
+					_tmp32_ = NULL;
+					_tmp31_ = NULL;
+					_tmp30_ = NULL;
+					vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) e), _tmp32_ = g_strdup_printf ("Expected initializer of type `%s' but got `%s'", _tmp30_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_target_type (e)), _tmp31_ = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (e))));
+					_tmp32_ = (g_free (_tmp32_), NULL);
+					_tmp31_ = (g_free (_tmp31_), NULL);
+					_tmp30_ = (g_free (_tmp30_), NULL);
 				}
 			}
 			(e == NULL) ? NULL : (e = (vala_code_node_unref (e), NULL));
@@ -741,17 +791,20 @@ static gboolean vala_initializer_list_real_check (ValaCodeNode* base, ValaSemant
 		}
 		(_e_it == NULL) ? NULL : (_e_it = (gee_collection_object_unref (_e_it), NULL));
 	}
-	if (!error) {
+	if (!_error_) {
 		/* everything seems to be correct */
 		vala_expression_set_value_type ((ValaExpression*) self, vala_expression_get_target_type ((ValaExpression*) self));
 	}
-	return !error;
+	result = !_error_;
+	return result;
 }
 
 
 gint vala_initializer_list_get_size (ValaInitializerList* self) {
+	gint result;
 	g_return_val_if_fail (self != NULL, 0);
-	return gee_collection_get_size ((GeeCollection*) self->priv->initializers);
+	result = gee_collection_get_size ((GeeCollection*) self->priv->initializers);
+	return result;
 }
 
 
