@@ -175,6 +175,7 @@ struct _ValaMemberInitializerPrivate {
 };
 
 
+static gpointer vala_member_initializer_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -219,7 +220,6 @@ static gboolean vala_member_initializer_real_check (ValaCodeNode* base, ValaSema
 const char* vala_member_initializer_get_name (ValaMemberInitializer* self);
 ValaSymbol* vala_member_initializer_get_symbol_reference (ValaMemberInitializer* self);
 void vala_member_initializer_set_symbol_reference (ValaMemberInitializer* self, ValaSymbol* value);
-static gpointer vala_member_initializer_parent_class = NULL;
 static void vala_member_initializer_finalize (ValaCodeNode* obj);
 
 
@@ -259,47 +259,55 @@ static void vala_member_initializer_real_accept (ValaCodeNode* base, ValaCodeVis
 
 static gboolean vala_member_initializer_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaMemberInitializer * self;
+	gboolean result;
 	self = (ValaMemberInitializer*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
-	return vala_code_node_check ((ValaCodeNode*) self->priv->_initializer, analyzer);
+	result = vala_code_node_check ((ValaCodeNode*) self->priv->_initializer, analyzer);
+	return result;
 }
 
 
 const char* vala_member_initializer_get_name (ValaMemberInitializer* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_name;
+	result = self->priv->_name;
+	return result;
 }
 
 
 void vala_member_initializer_set_name (ValaMemberInitializer* self, const char* value) {
-	char* _tmp2_;
-	const char* _tmp1_;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp1_);
 }
 
 
 ValaExpression* vala_member_initializer_get_initializer (ValaMemberInitializer* self) {
+	ValaExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_initializer;
+	result = self->priv->_initializer;
+	return result;
 }
 
 
 void vala_member_initializer_set_initializer (ValaMemberInitializer* self, ValaExpression* value) {
-	ValaExpression* _tmp2_;
 	ValaExpression* _tmp1_;
+	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_initializer = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_initializer = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_initializer == NULL) ? NULL : (self->priv->_initializer = (vala_code_node_unref (self->priv->_initializer), NULL)), _tmp1_);
 }
 
 
 ValaSymbol* vala_member_initializer_get_symbol_reference (ValaMemberInitializer* self) {
+	ValaSymbol* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_symbol_reference;
+	result = self->priv->_symbol_reference;
+	return result;
 }
 
 
