@@ -471,6 +471,16 @@ typedef struct _ValaSwitchSectionClass ValaSwitchSectionClass;
 typedef struct _ValaSwitchLabel ValaSwitchLabel;
 typedef struct _ValaSwitchLabelClass ValaSwitchLabelClass;
 
+#define VALA_TYPE_LOOP (vala_loop_get_type ())
+#define VALA_LOOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LOOP, ValaLoop))
+#define VALA_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LOOP, ValaLoopClass))
+#define VALA_IS_LOOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LOOP))
+#define VALA_IS_LOOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LOOP))
+#define VALA_LOOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LOOP, ValaLoopClass))
+
+typedef struct _ValaLoop ValaLoop;
+typedef struct _ValaLoopClass ValaLoopClass;
+
 #define VALA_TYPE_WHILE_STATEMENT (vala_while_statement_get_type ())
 #define VALA_WHILE_STATEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatement))
 #define VALA_WHILE_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementClass))
@@ -957,6 +967,7 @@ struct _ValaCodeVisitorClass {
 	void (*visit_switch_statement) (ValaCodeVisitor* self, ValaSwitchStatement* stmt);
 	void (*visit_switch_section) (ValaCodeVisitor* self, ValaSwitchSection* section);
 	void (*visit_switch_label) (ValaCodeVisitor* self, ValaSwitchLabel* label);
+	void (*visit_loop) (ValaCodeVisitor* self, ValaLoop* stmt);
 	void (*visit_while_statement) (ValaCodeVisitor* self, ValaWhileStatement* stmt);
 	void (*visit_do_statement) (ValaCodeVisitor* self, ValaDoStatement* stmt);
 	void (*visit_for_statement) (ValaCodeVisitor* self, ValaForStatement* stmt);
@@ -1021,7 +1032,6 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* ulong_type;
 	ValaDataType* size_t_type;
 	ValaDataType* ssize_t_type;
-	ValaDataType* uint64_type;
 	ValaDataType* int8_type;
 	ValaDataType* unichar_type;
 	ValaDataType* double_type;
@@ -1040,6 +1050,7 @@ struct _ValaSemanticAnalyzerClass {
 };
 
 
+static gpointer vala_typecheck_parent_class = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -1130,6 +1141,7 @@ GType vala_if_statement_get_type (void);
 GType vala_switch_statement_get_type (void);
 GType vala_switch_section_get_type (void);
 GType vala_switch_label_get_type (void);
+GType vala_loop_get_type (void);
 GType vala_while_statement_get_type (void);
 GType vala_do_statement_get_type (void);
 GType vala_for_statement_get_type (void);
@@ -1171,7 +1183,6 @@ GType vala_assignment_get_type (void);
 void vala_expression_set_value_type (ValaExpression* self, ValaDataType* value);
 static gboolean vala_typecheck_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
-static gpointer vala_typecheck_parent_class = NULL;
 static void vala_typecheck_finalize (ValaCodeNode* obj);
 
 
@@ -1215,8 +1226,10 @@ static void vala_typecheck_real_accept (ValaCodeNode* base, ValaCodeVisitor* vis
 
 static gboolean vala_typecheck_real_is_pure (ValaExpression* base) {
 	ValaTypeCheck * self;
+	gboolean result;
 	self = (ValaTypeCheck*) base;
-	return vala_expression_is_pure (self->priv->_expression);
+	result = vala_expression_is_pure (self->priv->_expression);
+	return result;
 }
 
 
@@ -1233,10 +1246,12 @@ static void vala_typecheck_real_replace_type (ValaCodeNode* base, ValaDataType*
 
 static gboolean vala_typecheck_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaTypeCheck * self;
+	gboolean result;
 	self = (ValaTypeCheck*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
-		return !vala_code_node_get_error ((ValaCodeNode*) self);
+		result = !vala_code_node_get_error ((ValaCodeNode*) self);
+		return result;
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	vala_code_node_check ((ValaCodeNode*) self->priv->_expression, analyzer);
@@ -1244,42 +1259,48 @@ static gboolean vala_typecheck_real_check (ValaCodeNode* base, ValaSemanticAnaly
 	if (vala_data_type_get_data_type (vala_typecheck_get_type_reference (self)) == NULL) {
 		/* if type resolving didn't succeed, skip this check */
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
 	vala_expression_set_value_type ((ValaExpression*) self, analyzer->bool_type);
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
 ValaExpression* vala_typecheck_get_expression (ValaTypeCheck* self) {
+	ValaExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_expression;
+	result = self->priv->_expression;
+	return result;
 }
 
 
 void vala_typecheck_set_expression (ValaTypeCheck* self, ValaExpression* value) {
-	ValaExpression* _tmp2_;
 	ValaExpression* _tmp1_;
+	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_expression = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp1_);
 }
 
 
 ValaDataType* vala_typecheck_get_type_reference (ValaTypeCheck* self) {
+	ValaDataType* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_data_type;
+	result = self->priv->_data_type;
+	return result;
 }
 
 
 void vala_typecheck_set_type_reference (ValaTypeCheck* self, ValaDataType* value) {
-	ValaDataType* _tmp2_;
 	ValaDataType* _tmp1_;
+	ValaDataType* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_data_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_data_type = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp1_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 }
 
