@@ -187,6 +187,8 @@ struct _ValaYieldStatementPrivate {
 };
 
 
+static gpointer vala_yield_statement_parent_class = NULL;
+static ValaStatementIface* vala_yield_statement_vala_statement_parent_iface = NULL;
 
 gpointer vala_code_node_ref (gpointer instance);
 void vala_code_node_unref (gpointer instance);
@@ -235,8 +237,6 @@ gboolean vala_code_node_get_error (ValaCodeNode* self);
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 static gboolean vala_yield_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
-static gpointer vala_yield_statement_parent_class = NULL;
-static ValaStatementIface* vala_yield_statement_vala_statement_parent_iface = NULL;
 static void vala_yield_statement_finalize (ValaCodeNode* obj);
 
 
@@ -294,29 +294,33 @@ static void vala_yield_statement_real_replace_expression (ValaCodeNode* base, Va
 
 static gboolean vala_yield_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaYieldStatement * self;
+	gboolean result;
 	self = (ValaYieldStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_yield_statement_get_yield_expression (self) != NULL) {
 		vala_code_node_check ((ValaCodeNode*) vala_yield_statement_get_yield_expression (self), analyzer);
 		vala_code_node_set_error ((ValaCodeNode*) self, vala_code_node_get_error ((ValaCodeNode*) vala_yield_statement_get_yield_expression (self)));
 	}
-	return !vala_code_node_get_error ((ValaCodeNode*) self);
+	result = !vala_code_node_get_error ((ValaCodeNode*) self);
+	return result;
 }
 
 
 ValaExpression* vala_yield_statement_get_yield_expression (ValaYieldStatement* self) {
+	ValaExpression* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_yield_expression;
+	result = self->priv->_yield_expression;
+	return result;
 }
 
 
 void vala_yield_statement_set_yield_expression (ValaYieldStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp2_;
 	ValaExpression* _tmp1_;
+	ValaExpression* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2_ = NULL;
 	_tmp1_ = NULL;
-	self->priv->_yield_expression = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_yield_expression == NULL) ? NULL : (self->priv->_yield_expression = (vala_code_node_unref (self->priv->_yield_expression), NULL)), _tmp2_);
+	_tmp0_ = NULL;
+	self->priv->_yield_expression = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_)), (self->priv->_yield_expression == NULL) ? NULL : (self->priv->_yield_expression = (vala_code_node_unref (self->priv->_yield_expression), NULL)), _tmp1_);
 	if (self->priv->_yield_expression != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_yield_expression, (ValaCodeNode*) self);
 	}
